==> wpewebkit_2.36.0.orig.tar.xz: wpewebkit-2.36.0/Source/WebKit/UIProcess/QuickLookThumbnailLoader.h <==
/*
* Copyright (C) 2020 Apple Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
*
* THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
* THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
* PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
* THE POSSIBILITY OF SUCH DAMAGE.
*/

#if HAVE(QUICKLOOK_THUMBNAILING)

#import "CocoaImage.h"

@interface WKQLThumbnailQueueManager : NSObject

@property (nonatomic, readonly, retain) NSOperationQueue *queue;

- (instancetype)init;
+ (WKQLThumbnailQueueManager *)sharedInstance;

@end

@interface WKQLThumbnailLoadOperation : NSOperation

@property (atomic, readonly, getter=isAsynchronous) BOOL asynchronous;
@property (atomic, readonly, getter=isExecuting) BOOL executing;
@property (atomic, readonly, getter=isFinished) BOOL finished;

@property (nonatomic, readonly, copy) NSString *identifier;
@property (nonatomic, readonly, retain) CocoaImage *thumbnail;

- (instancetype)initWithAttachment:(NSFileWrapper *)fileWrapper identifier:(NSString *)identifier;
- (instancetype)initWithURL:(NSString *)fileURL identifier:(NSString *)identifier;

@end

#endif // HAVE(QUICKLOOK_THUMBNAILING)

==> wpewebkit_2.38.6.orig.tar.xz: wpewebkit-2.38.6/Source/WebKit/UIProcess/QuickLookThumbnailLoader.h <==
/*
* Copyright (C) 2020 Apple Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
*
* THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
* THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
* PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
* THE POSSIBILITY OF SUCH DAMAGE.
*/

#if HAVE(QUICKLOOK_THUMBNAILING)

#import "CocoaImage.h"

namespace API {
class Attachment;
}

@interface WKQLThumbnailQueueManager : NSObject

@property (nonatomic, readonly, retain) NSOperationQueue *queue;

- (instancetype)init;
+ (WKQLThumbnailQueueManager *)sharedInstance;

@end

@interface WKQLThumbnailLoadOperation : NSOperation

@property (atomic, readonly, getter=isAsynchronous) BOOL asynchronous;
@property (atomic, readonly, getter=isExecuting) BOOL executing;
@property (atomic, readonly, getter=isFinished) BOOL finished;

@property (nonatomic, readonly, copy) NSString *identifier;
@property (nonatomic, readonly, retain) CocoaImage *thumbnail;

- (instancetype)initWithAttachment:(const API::Attachment&)attachment identifier:(NSString *)identifier;
- (instancetype)initWithURL:(NSString *)fileURL identifier:(NSString *)identifier;

@end

#endif // HAVE(QUICKLOOK_THUMBNAILING)
